Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(591)

Unified Diff: content/browser/ssl/ssl_policy.h

Issue 2327433002: Stop using CertStore which is not compatible with PlzNavigate. (Closed)
Patch Set: remove cert_store on ios Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/ssl/ssl_manager.cc ('k') | content/browser/ssl/ssl_policy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/ssl/ssl_policy.h
diff --git a/content/browser/ssl/ssl_policy.h b/content/browser/ssl/ssl_policy.h
index 1e174d2325b500dc528cec05bb2de8c5635a47c5..f7c0496fe5329b6bf55c50f0438bc7ccace3a501 100644
--- a/content/browser/ssl/ssl_policy.h
+++ b/content/browser/ssl/ssl_policy.h
@@ -41,10 +41,10 @@ class CONTENT_EXPORT SSLPolicy {
void DidRunContentWithCertErrors(NavigationEntryImpl* entry,
const GURL& security_origin);
// We have started a resource request for |url| with the given |cert_id| and
// |cert_status|.
void OnRequestStarted(const GURL& url,
- int cert_id,
+ bool has_certificate,
net::CertStatus cert_status);
// Update the SSL information in |entry| to match the current state.
« no previous file with comments | « content/browser/ssl/ssl_manager.cc ('k') | content/browser/ssl/ssl_policy.cc » ('j') | no next file with comments »
@@ -41,10 +41,10 @@ class CONTENT_EXPORT SSLPolicy {
void DidRunContentWithCertErrors(NavigationEntryImpl* entry,
const GURL& security_origin);
- // We have started a resource request for |url| with the given |cert_id| and
- // |cert_status|.
+ // We have started a resource request for |url| and if it has a certificate
+ // and |cert_status|.
void OnRequestStarted(const GURL& url,

Powered by Google App Engine
This is Rietveld 408576698